package geniusweb.simplerunner.gui;

import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;

import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.table.TableModel;

import geniusweb.protocol.session.TeamInfo;
import geniusweb.references.PartyWithProfile;

/**
 * The selected parties, profiles etc
 *
 */
public class SelectionModel implements TableModel {
	private final List<TeamInfo> teams = new LinkedList<>();
	private final List<TableModelListener> listeners = new LinkedList<>();

	private final List<String> colnames = Arrays.asList("Party", "Parameters",
			"Profile");

	public List<TeamInfo> getTeams() {
		return teams;
	}

	public void addTeam(TeamInfo team) {
		teams.add(team);
		notifyListeners();
	}

	private void notifyListeners() {
		for (TableModelListener l : listeners) {
			l.tableChanged(new TableModelEvent(this));
		}
	}

	@Override
	public int getRowCount() {
		return teams.size();
	}

	@Override
	public int getColumnCount() {
		return 3;
	}

	@Override
	public String getColumnName(int columnIndex) {
		return colnames.get(columnIndex);
	}

	@Override
	public Class<?> getColumnClass(int columnIndex) {
		return String.class;
	}

	@Override
	public boolean isCellEditable(int rowIndex, int columnIndex) {
		return false;
	}

	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		PartyWithProfile party = teams.get(rowIndex).getParties().get(0);
		switch (columnIndex) {
		case 0:
			return party.getParty().getPartyRef().getURI().toString();
		case 1:
			return party.getParty().getParameters().toString();
		case 2:
			return party.getProfile().getURI().toString();
		}
		return null;
	}

	@Override
	public void setValueAt(Object aValue, int rowIndex, int columnIndex) {
		throw new UnsupportedOperationException();
	}

	@Override
	public void addTableModelListener(TableModelListener l) {
		listeners.add(l);
	}

	@Override
	public void removeTableModelListener(TableModelListener l) {
		listeners.remove(l);
	}

}
